# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

from datetime import date

project = 'itkwasm-image-io'
copyright = f'{date.today().year}, NumFOCUS'
author = 'Insight Software Consortium'

extensions = [
    'sphinx.ext.autosummary',
    'autodoc2',
    'myst_parser',
    'sphinx.ext.intersphinx',
    'sphinx_copybutton',
    'sphinxext.opengraph',
    'sphinx_design',
]

myst_enable_extensions = ["colon_fence", "fieldlist"]

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

autodoc2_packages = [
    {
        "path": "../itkwasm_image_io",
        "exclude_files": ["_version.py"],
    },
]
autodoc2_render_plugin = "myst"

intersphinx_mapping = {
    "python": ("https://docs.python.org/3/", None),
    "numpy": ("https://numpy.org/doc/stable", None),
    "itkwasm": ("https://itkwasm.readthedocs.io/en/latest/", None),
}

html_theme = 'furo'
html_static_path = ['_static']
html_logo = "_static/logo.svg"
html_favicon = "_static/favicon.png"
html_title = f"{project}"

# Furo options
html_theme_options = {
    "top_of_page_button": "edit",
    "source_repository": "https://github.com/InsightSoftwareConsortium/itk-wasm",
    "source_branch": "main",
    "source_directory": "docs",
}


import os
from typing import Optional, Union

from itkwasm import (
    environment_dispatch,
    Image,
    PixelTypes,
    IntTypes,
    FloatTypes,
)

def read_image(
    serialized_image: os.PathLike,
    information_only: bool = False,
    pixel_type: Optional[PixelTypes]=None,
    component_type: Optional[Union[IntTypes, FloatTypes]]=None,
) -> Image:
    """Read an image file format and convert it to the itk-wasm file format

    :param serialized_image: Input image serialized in the file format
    :type  serialized_image: os.PathLike

    :param information_only: Only read image metadata -- do not read pixel data.
    :type  information_only: bool

    :param pixel_type: Pixel type to cast to.
    :type  pixel_Type: Optional[PixelTypes]

    :param component_type: Component type to cast to.
    :type  component_type: Optional[Union[IntTypes, FloatTypes]]

    :return: Output image
    :rtype:  Image
    """
    func = environment_dispatch("itkwasm_image_io", "read_image")
    output = func(serialized_image, information_only=information_only, pixel_type=pixel_type, component_type=component_type)
    return output

def imread(
    serialized_image: os.PathLike,
    information_only: bool = False,
    pixel_type: Optional[PixelTypes]=None,
    component_type: Optional[Union[IntTypes, FloatTypes]]=None,
) -> Image:
    return read_image(serialized_image, information_only=information_only, pixel_type=pixel_type, component_type=component_type)

imread.__doc__ = f"""{read_image.__doc__}
    Alias for read_image.
    """


from pathlib import Path

test_input_path = Path(__file__).parent / ".." / ".." / ".." / "test" / "data" / "input"
test_baseline_path = Path(__file__).parent / ".." / ".." / ".." / "test" / "data" / "baseline"
test_output_path = Path(__file__).parent / ".." / ".." / ".." / "test" / "data" / "python"
test_output_path.mkdir(parents=True, exist_ok=True)


# Generated file. Do not edit.

import os
from typing import Dict, Tuple, Optional, List, Any

from itkwasm import (
    environment_dispatch,
    BinaryFile,
    Image,
)

def tiff_read_image(
    serialized_image: os.PathLike,
    information_only: bool = False,
) -> Tuple[Any, Image]:
    """Read an image file format and convert it to the itk-wasm file format

    :param serialized_image: Input image serialized in the file format
    :type  serialized_image: os.PathLike

    :param information_only: Only read image metadata -- do not read pixel data.
    :type  information_only: bool

    :return: Whether the input could be read. If false, the output image is not valid.
    :rtype:  Any

    :return: Output image
    :rtype:  Image
    """
    func = environment_dispatch("itkwasm_image_io", "tiff_read_image")
    output = func(serialized_image, information_only=information_only)
    return output



# Generated file. To retain edits, remove this comment.

"""itkwasm-image-io: Input and output for scientific and medical image file formats."""

from .read_image import read_image, imread
from .write_image import write_image, imwrite

from .bio_rad_read_image_async import bio_rad_read_image_async
from .bio_rad_read_image import bio_rad_read_image
from .bio_rad_write_image_async import bio_rad_write_image_async
from .bio_rad_write_image import bio_rad_write_image
from .bmp_read_image_async import bmp_read_image_async
from .bmp_read_image import bmp_read_image
from .bmp_write_image_async import bmp_write_image_async
from .bmp_write_image import bmp_write_image
from .fdf_read_image_async import fdf_read_image_async
from .fdf_read_image import fdf_read_image
from .fdf_write_image_async import fdf_write_image_async
from .fdf_write_image import fdf_write_image
from .gdcm_read_image_async import gdcm_read_image_async
from .gdcm_read_image import gdcm_read_image
from .gdcm_write_image_async import gdcm_write_image_async
from .gdcm_write_image import gdcm_write_image
from .ge_adw_read_image_async import ge_adw_read_image_async
from .ge_adw_read_image import ge_adw_read_image
from .ge_adw_write_image_async import ge_adw_write_image_async
from .ge_adw_write_image import ge_adw_write_image
from .ge4_read_image_async import ge4_read_image_async
from .ge4_read_image import ge4_read_image
from .ge4_write_image_async import ge4_write_image_async
from .ge4_write_image import ge4_write_image
from .ge5_read_image_async import ge5_read_image_async
from .ge5_read_image import ge5_read_image
from .ge5_write_image_async import ge5_write_image_async
from .ge5_write_image import ge5_write_image
from .gipl_read_image_async import gipl_read_image_async
from .gipl_read_image import gipl_read_image
from .gipl_write_image_async import gipl_write_image_async
from .gipl_write_image import gipl_write_image
from .jpeg_read_image_async import jpeg_read_image_async
from .jpeg_read_image import jpeg_read_image
from .jpeg_write_image_async import jpeg_write_image_async
from .jpeg_write_image import jpeg_write_image
from .lsm_read_image_async import lsm_read_image_async
from .lsm_read_image import lsm_read_image
from .lsm_write_image_async import lsm_write_image_async
from .lsm_write_image import lsm_write_image
from .meta_read_image_async import meta_read_image_async
from .meta_read_image import meta_read_image
from .meta_write_image_async import meta_write_image_async
from .meta_write_image import meta_write_image
from .mgh_read_image_async import mgh_read_image_async
from .mgh_read_image import mgh_read_image
from .mgh_write_image_async import mgh_write_image_async
from .mgh_write_image import mgh_write_image
from .mrc_read_image_async import mrc_read_image_async
from .mrc_read_image import mrc_read_image
from .mrc_write_image_async import mrc_write_image_async
from .mrc_write_image import mrc_write_image
from .nifti_read_image_async import nifti_read_image_async
from .nifti_read_image import nifti_read_image
from .nifti_write_image_async import nifti_write_image_async
from .nifti_write_image import nifti_write_image
from .nrrd_read_image_async import nrrd_read_image_async
from .nrrd_read_image import nrrd_read_image
from .nrrd_write_image_async import nrrd_write_image_async
from .nrrd_write_image import nrrd_write_image
from .png_read_image_async import png_read_image_async
from .png_read_image import png_read_image
from .png_write_image_async import png_write_image_async
from .png_write_image import png_write_image
from .scanco_read_image_async import scanco_read_image_async
from .scanco_read_image import scanco_read_image
from .scanco_write_image_async import scanco_write_image_async
from .scanco_write_image import scanco_write_image
from .tiff_read_image_async import tiff_read_image_async
from .tiff_read_image import tiff_read_image
from .tiff_write_image_async import tiff_write_image_async
from .tiff_write_image import tiff_write_image
from .vtk_read_image_async import vtk_read_image_async
from .vtk_read_image import vtk_read_image
from .vtk_write_image_async import vtk_write_image_async
from .vtk_write_image import vtk_write_image
from .wasm_read_image_async import wasm_read_image_async
from .wasm_read_image import wasm_read_image
from .wasm_write_image_async import wasm_write_image_async
from .wasm_write_image import wasm_write_image
from .wasm_zstd_read_image_async import wasm_zstd_read_image_async
from .wasm_zstd_read_image import wasm_zstd_read_image
from .wasm_zstd_write_image_async import wasm_zstd_write_image_async
from .wasm_zstd_write_image import wasm_zstd_write_image

from ._version import __version__



from itkwasm_image_io import png_read_image, png_write_image

from .common import test_input_path, test_output_path

test_input_file_path = test_input_path / "cthead1.png"
test_output_file_path = test_output_path / "png-test-cthead1.png"

def verify_image(image):
    assert image.imageType.dimension == 2
    assert image.imageType.componentType == "uint8"
    assert image.imageType.pixelType == "RGB"
    assert image.imageType.components == 3
    assert image.origin[0] == 0.0
    assert image.origin[1] == 0.0
    assert image.spacing[0] == 1.0
    assert image.spacing[1] == 1.0
    assert image.direction[0, 0] == 1.0
    assert image.direction[0, 1] == 0.0
    assert image.direction[1, 0] == 0.0
    assert image.direction[1, 1] == 1.0
    assert image.size[0] == 256
    assert image.size[1] == 256
    assert image.data.shape[1] == 256
    assert image.data.shape[0] == 256

def test_png_read_image():
    could_read, image = png_read_image(test_input_file_path)
    assert could_read
    verify_image(image)

def test_png_write_image():
    could_read, image = png_read_image(test_input_file_path)
    assert could_read

    use_compression = False
    could_write = png_write_image(image, test_output_file_path, use_compression)
    assert could_write

    could_read, image = png_read_image(test_output_file_path)
    assert could_read
    verify_image(image)


# Generated file. Do not edit.

import os
from typing import Dict, Tuple, Optional, List, Any

from itkwasm import (
    environment_dispatch,
    Image,
    BinaryFile,
)

def wasm_zstd_write_image(
    image: Image,
    serialized_image: str,
    information_only: bool = False,
    use_compression: bool = False,
) -> Tuple[Any]:
    """Write an itk-wasm file format converted to an image file format

    :param image: Input image
    :type  image: Image

    :param serialized_image: Output image serialized in the file format.
    :type  serialized_image: str

    :param information_only: Only write image metadata -- do not write pixel data.
    :type  information_only: bool

    :param use_compression: Use compression in the written file
    :type  use_compression: bool

    :return: Whether the input could be written. If false, the output image is not valid.
    :rtype:  Any
    """
    func = environment_dispatch("itkwasm_image_io", "wasm_zstd_write_image")
    output = func(image, serialized_image, information_only=information_only, use_compression=use_compression)
    return output



from pathlib import Path

from itkwasm import PixelTypes, IntTypes

from itkwasm_image_io import read_image, imread, write_image, imwrite

from .common import test_input_path, test_output_path

test_input_file_path = test_input_path / "cthead1.png"
test_output_file_path = test_output_path / "read-write-cthead1.png"

def verify_image(image):
    assert image.imageType.dimension == 2
    assert image.imageType.componentType == "uint8"
    assert image.imageType.pixelType == "RGB"
    assert image.imageType.components == 3
    assert image.origin[0] == 0.0
    assert image.origin[1] == 0.0
    assert image.spacing[0] == 1.0
    assert image.spacing[1] == 1.0
    assert image.direction[0, 0] == 1.0
    assert image.direction[0, 1] == 0.0
    assert image.direction[1, 0] == 0.0
    assert image.direction[1, 1] == 1.0
    assert image.size[0] == 256
    assert image.size[1] == 256
    assert image.data.shape[1] == 256
    assert image.data.shape[0] == 256

def test_read_image():
    image = read_image(test_input_file_path)
    verify_image(image)

def test_read_image_pixel_type():
    image = read_image(test_input_file_path, pixel_type=PixelTypes.Vector)
    assert image.imageType.pixelType == "Vector"

def test_read_image_component_type():
    image = read_image(test_input_file_path, component_type=IntTypes.UInt16)
    assert image.imageType.componentType == "uint16"

def test_imread():
    image = imread(test_input_file_path)
    verify_image(image)

def test_write_image():
    image = read_image(test_input_file_path)

    use_compression = False
    write_image(image, test_output_file_path, use_compression=use_compression)

    image = read_image(test_output_file_path)
    verify_image(image)

def test_imwrite():
    image = imread(test_input_file_path)

    use_compression = False
    imwrite(image, test_output_file_path, use_compression=use_compression)

    image = imread(test_output_file_path)
    verify_image(image)
